#!/bin/bash

# ufl-analyse output
rm -f *_debug.py

# python compiled files
rm -f *.pyc

# logs
rm -f *.log

# temp files from emacs
rm -f *~

